@@ -26,4 +26,11 @@ sub _create_element {
 
 #Note: all canvas related methods are inherited from IUP::Internal::Canvas
 
+#FIXME-hack
+package IUP::Canvas::Bitmap;
+package IUP::Canvas::Palette;
+package IUP::Canvas::Pattern;
+package IUP::Canvas::Stipple;
+package IUP::Canvas::InternalServerImage;
+
 1;
